summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--README2
-rw-r--r--cmake/FindCairo.cmake14
-rw-r--r--cmake/FindGettext.cmake4
-rw-r--r--cmake/FindSDL.cmake4
-rw-r--r--cmake/FindSDL_image.cmake4
-rw-r--r--cmake/FindSDL_mixer.cmake4
-rw-r--r--cmake/FindSDL_ttf.cmake4
-rw-r--r--cmake/FindZIP.cmake4
-rw-r--r--packaging/gentoo/tuxanci-9999.ebuild10
-rw-r--r--src/audio/audio.c6
-rw-r--r--src/audio/music.c26
-rw-r--r--src/audio/sound.c20
12 files changed, 51 insertions, 51 deletions
diff --git a/README b/README
index 28311fa..59b6923 100644
--- a/README
+++ b/README
@@ -139,7 +139,7 @@ HAVE PROBLEM/FOUND BUG/ETC...
http://www.tuxanci.org/buglist (you need account for that).
You need some help with install/etc... feel free to join us on our irc
- channel which is #tuxanci on server irc.tuxportal.cz. If you don't like
+ channel which is #tuxanci on server irc.freenode.net. If you don't like
irc you can can contact us on our forum also: http://czf.tuxanci.org.
INFORMATIONS FOR TRANSLATORS
diff --git a/cmake/FindGettext.cmake b/cmake/FindGettext.cmake
index f14922e..494d8b0 100644
--- a/cmake/FindGettext.cmake
+++ b/cmake/FindGettext.cmake
@@ -24,17 +24,17 @@ FIND_PATH(GETTEXT_INCLUDE_DIR libintl.h
FIND_PROGRAM(GETTEXT_MSGMERGE_EXECUTABLE msgmerge
PATHS
- ${CMAKE_SOURCE_DIR}/packaging/windows/Gettext/exe/
/usr/local/bin
/usr/bin
+ ${CMAKE_SOURCE_DIR}/packaging/windows/Gettext/exe/
NO_DEFAULT_PATH
)
FIND_PROGRAM(GETTEXT_MSGFMT_EXECUTABLE msgfmt
PATHS
- ${CMAKE_SOURCE_DIR}/packaging/windows/Gettext/exe/
/usr/local/bin
/usr/bin
+ ${CMAKE_SOURCE_DIR}/packaging/windows/Gettext/exe/
NO_DEFAULT_PATH
)
diff --git a/cmake/FindSDL.cmake b/cmake/FindSDL.cmake
index 3c22b3b..5240357 100644
--- a/cmake/FindSDL.cmake
+++ b/cmake/FindSDL.cmake
@@ -67,7 +67,6 @@ FIND_PATH(SDL_INCLUDE_DIR SDL.h
/usr/include/SDL11
/usr/local/include
/usr/include
- ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/include #tuxanci
/sw/include/SDL # Fink
/sw/include
/opt/local/include/SDL # DarwinPorts
@@ -76,6 +75,7 @@ FIND_PATH(SDL_INCLUDE_DIR SDL.h
/opt/csw/include
/opt/include/SDL
/opt/include
+ ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/include #tuxanci
)
#MESSAGE("SDL_INCLUDE_DIR is ${SDL_INCLUDE_DIR}")
@@ -109,13 +109,13 @@ IF(NOT SDL_BUILDING_LIBRARY)
$ENV{SDLDIR}
PATH_SUFFIXES lib64 lib
PATHS
- ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/
/usr/local
/usr
/sw
/opt/local
/opt/csw
/opt
+ ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/
)
ENDIF(NOT ${SDL_INCLUDE_DIR} MATCHES ".framework")
ENDIF(NOT SDL_BUILDING_LIBRARY)
diff --git a/cmake/FindSDL_image.cmake b/cmake/FindSDL_image.cmake
index 114924a..a6dddf6 100644
--- a/cmake/FindSDL_image.cmake
+++ b/cmake/FindSDL_image.cmake
@@ -30,13 +30,13 @@ FIND_PATH(SDLIMAGE_INCLUDE_DIR SDL_image.h
/usr/include
/sw/include/SDL # Fink
/sw/include
- ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/include #tuxanci
/opt/local/include/SDL # DarwinPorts
/opt/local/include
/opt/csw/include/SDL # Blastwave
/opt/csw/include
/opt/include/SDL
/opt/include
+ ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/include #tuxanci
)
FIND_LIBRARY(SDLIMAGE_LIBRARY
@@ -46,7 +46,6 @@ FIND_LIBRARY(SDLIMAGE_LIBRARY
$ENV{SDLDIR}
PATH_SUFFIXES lib64 lib
PATHS
- ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/
~/Library/Frameworks
/Library/Frameworks
/usr/local
@@ -55,6 +54,7 @@ FIND_LIBRARY(SDLIMAGE_LIBRARY
/opt/local
/opt/csw
/opt
+ ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/
)
SET(SDLIMAGE_FOUND "NO")
diff --git a/cmake/FindSDL_mixer.cmake b/cmake/FindSDL_mixer.cmake
index b3bd845..f491d02 100644
--- a/cmake/FindSDL_mixer.cmake
+++ b/cmake/FindSDL_mixer.cmake
@@ -30,13 +30,13 @@ FIND_PATH(SDLMIXER_INCLUDE_DIR SDL_mixer.h
/usr/include
/sw/include/SDL # Fink
/sw/include
- ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/include #tuxanci
/opt/local/include/SDL # DarwinPorts
/opt/local/include
/opt/csw/include/SDL # Blastwave
/opt/csw/include
/opt/include/SDL
/opt/include
+ ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/include #tuxanci
)
FIND_LIBRARY(SDLMIXER_LIBRARY
@@ -46,7 +46,6 @@ FIND_LIBRARY(SDLMIXER_LIBRARY
$ENV{SDLDIR}
PATH_SUFFIXES lib64 lib
PATHS
- ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/
~/Library/Frameworks
/Library/Frameworks
/usr/local
@@ -55,6 +54,7 @@ FIND_LIBRARY(SDLMIXER_LIBRARY
/opt/local
/opt/csw
/opt
+ ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/
)
SET(SDLMIXER_FOUND "NO")
diff --git a/cmake/FindSDL_ttf.cmake b/cmake/FindSDL_ttf.cmake
index 10ec40a..32dbbad 100644
--- a/cmake/FindSDL_ttf.cmake
+++ b/cmake/FindSDL_ttf.cmake
@@ -30,13 +30,13 @@ FIND_PATH(SDLTTF_INCLUDE_DIR SDL_ttf.h
/usr/include
/sw/include/SDL # Fink
/sw/include
- ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/include #tuxanci
/opt/local/include/SDL # DarwinPorts
/opt/local/include
/opt/csw/include/SDL # Blastwave
/opt/csw/include
/opt/include/SDL
/opt/include
+ ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/include #tuxanci
)
FIND_LIBRARY(SDLTTF_LIBRARY
@@ -45,7 +45,6 @@ FIND_LIBRARY(SDLTTF_LIBRARY
$ENV{SDLTTFDIR}
$ENV{SDLDIR}
PATHS
- ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/
~/Library/Frameworks
/Library/Frameworks
/usr/local
@@ -54,6 +53,7 @@ FIND_LIBRARY(SDLTTF_LIBRARY
/opt/local
/opt/csw
/opt
+ ${CMAKE_SOURCE_DIR}/packaging/windows/SDL/
PATH_SUFFIXES lib64 lib
)
diff --git a/cmake/FindZIP.cmake b/cmake/FindZIP.cmake
index e50aedf..bbc3765 100644
--- a/cmake/FindZIP.cmake
+++ b/cmake/FindZIP.cmake
@@ -12,18 +12,18 @@ IF(ZIP_LIBRARIES AND ZIP_INCLUDE_DIR)
ELSE(ZIP_LIBRARIES AND ZIP_INCLUDE_DIR)
FIND_PATH(ZIP_INCLUDE_DIR zip.h
PATHS
- ${CMAKE_SOURCE_DIR}/packaging/windows/LibZip/include
/usr/local/include
/usr/include
+ ${CMAKE_SOURCE_DIR}/packaging/windows/LibZip/include
NO_DEFAULT_PATH
)
FIND_LIBRARY(ZIP_LIBRARIES NAMES zip zip-1
PATH_SUFFIXES lib64 lib
PATHS
- ${CMAKE_SOURCE_DIR}/packaging/windows/LibZip/
/usr/local
/usr
+ ${CMAKE_SOURCE_DIR}/packaging/windows/LibZip/
)
# handle the QUIETLY and REQUIRED arguments and set ZIP_FOUND to TRUE if
diff --git a/packaging/gentoo/tuxanci-9999.ebuild b/packaging/gentoo/tuxanci-9999.ebuild
index 672e9aa..255f3a5 100644
--- a/packaging/gentoo/tuxanci-9999.ebuild
+++ b/packaging/gentoo/tuxanci-9999.ebuild
@@ -1,4 +1,4 @@
-# Copyright 1999-2008 Gentoo Foundation
+# Copyright 1999-2009 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $
@@ -20,7 +20,7 @@ LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~amd64 ~x86"
-IUSE="alsa debug dedicated ipv6 nls opengl"
+IUSE="debug dedicated +ipv6 nls opengl +sound"
# alsa is used only when building client
RDEPEND="
@@ -30,7 +30,7 @@ RDEPEND="
media-libs/sdl-ttf[X]
media-libs/sdl-image[png]
x11-libs/cairo[X,svg]
- alsa? (
+ sound? (
media-libs/sdl-mixer[vorbis]
)
)
@@ -39,13 +39,13 @@ DEPEND="${RDEPEND}
nls? ( sys-devel/gettext )"
src_configure() {
- local mycmakeargs="$(cmake-utils_use_with alsa AUDIO)
+ local mycmakeargs="$(cmake-utils_use_with sound AUDIO)
$(cmake-utils_use_enable debug)
$(cmake-utils_use_build dedicated SERVER)
$(cmake-utils_use_with nls)
$(cmake-utils_use_with opengl)
$(cmake-utils_use_enable ipv6)
- $(cmake_utils_use_enable debug)"
+ $(cmake-utils_use_enable debug)"
mycmakeargs="${mycmakeargs}
-DCMAKE_INSTALL_PREFIX=${GAMES_PREFIX}
diff --git a/src/audio/audio.c b/src/audio/audio.c
index 6e5c051..9b6d9fc 100644
--- a/src/audio/audio.c
+++ b/src/audio/audio.c
@@ -8,7 +8,7 @@
static bool_t isAudioInit = FALSE;
-/*
+/**
* Return status of audio
*/
bool_t audio_is_inicialized()
@@ -16,7 +16,7 @@ bool_t audio_is_inicialized()
return isAudioInit;
}
-/*
+/**
* Initialize audio
*/
void audio_init()
@@ -43,7 +43,7 @@ void audio_init()
isAudioInit = TRUE;
}
-/*
+/**
* Shutdown audio
*/
void audio_quit()
diff --git a/src/audio/music.c b/src/audio/music.c
index 2d2194f..90dd321 100644
--- a/src/audio/music.c
+++ b/src/audio/music.c
@@ -15,7 +15,7 @@ static bool_t isMusicInit = FALSE;
static bool_t var_music_is_active = TRUE;
static Mix_Music *currentMusic;
-/*
+/**
* Return status of music
*/
bool_t music_is_inicialized()
@@ -23,7 +23,7 @@ bool_t music_is_inicialized()
return isMusicInit;
}
-/*
+/**
* Initialize music
*/
void music_init()
@@ -47,7 +47,7 @@ void music_init()
}
}
-/*
+/**
* Load a file with music and returns it
*/
static Mix_Music *loadMixMusic(char *file)
@@ -75,7 +75,7 @@ static Mix_Music *loadMixMusic(char *file)
return mixer;
}
-/*
+/**
* Prepare the music mixer
*/
static void playMixMusic()
@@ -85,7 +85,7 @@ static void playMixMusic()
}
}
-/*
+/**
* Remove music from the memory
*/
static void destroyMusic(void *p)
@@ -93,7 +93,7 @@ static void destroyMusic(void *p)
Mix_FreeMusic((Mix_Music *) p);
}
-/*
+/**
* Add a file to the music list
*/
void music_add(char *file, char *name, char *group)
@@ -112,7 +112,7 @@ void music_add(char *file, char *name, char *group)
storage_add(listStorage, group, name, new);
}
-/*
+/**
* Stop playing music
*/
void music_stop()
@@ -129,7 +129,7 @@ void music_stop()
}
}
-/*
+/**
* Play music playback
*/
void music_play(char *name, char *group)
@@ -169,7 +169,7 @@ void music_play(char *name, char *group)
}
}
-/*
+/**
* Set music status to active/inactive
*/
void music_set_active(bool_t n)
@@ -187,7 +187,7 @@ void music_set_active(bool_t n)
var_music_is_active = n;
}
-/*
+/**
* Return the activity status of music
*/
bool_t music_is_active()
@@ -195,7 +195,7 @@ bool_t music_is_active()
return var_music_is_active;
}
-/*
+/**
* Return the music playing right now
*/
char *music_get_current()
@@ -203,7 +203,7 @@ char *music_get_current()
return "unknown";
}
-/*
+/**
* Remove all music files belonging to the certain group
*/
void music_del_all_in_group(char *group)
@@ -215,7 +215,7 @@ void music_del_all_in_group(char *group)
storage_del_all(listStorage, group, destroyMusic);
}
-/*
+/**
* Shutdown music
*/
void music_quit()
diff --git a/src/audio/sound.c b/src/audio/sound.c
index 58a78ba..f45ed80 100644
--- a/src/audio/sound.c
+++ b/src/audio/sound.c
@@ -13,7 +13,7 @@ static list_t *listStorage;
static bool_t isSoundInit = FALSE;
static bool_t var_sound_is_active = TRUE;
-/*
+/**
* Return status of sound
*/
bool_t sound_is_inicialized()
@@ -21,7 +21,7 @@ bool_t sound_is_inicialized()
return isSoundInit;
}
-/*
+/**
* Initialize sound
*/
void sound_init()
@@ -44,7 +44,7 @@ void sound_init()
}
}
-/*
+/**
* Load sound from file (Null/mixer)
*/
static Mix_Chunk *loadMixSound(char *file)
@@ -66,7 +66,7 @@ static Mix_Chunk *loadMixSound(char *file)
return new;
}
-/*
+/**
* Play sound with mixer
*/
static void playMixSound(Mix_Chunk *p)
@@ -77,7 +77,7 @@ static void playMixSound(Mix_Chunk *p)
}
}
-/*
+/**
* Destroy mixer chunk
*/
static void destroySound(void *p)
@@ -85,7 +85,7 @@ static void destroySound(void *p)
Mix_FreeChunk((Mix_Chunk *) p);
}
-/*
+/**
* Add a sound to list
*/
void sound_add(char *file, char *name, char *group)
@@ -104,7 +104,7 @@ void sound_add(char *file, char *name, char *group)
storage_add(listStorage, group, name, new);
}
-/*
+/**
* Start playing a sound from a file from the list
*/
void sound_play(char *name, char *group)
@@ -116,7 +116,7 @@ void sound_play(char *name, char *group)
playMixSound(storage_get(listStorage, group, name));
}
-/*
+/**
* Set sound status to active/inactive (true/false)
*/
void sound_set_active(bool_t n)
@@ -124,7 +124,7 @@ void sound_set_active(bool_t n)
var_sound_is_active = n;
}
-/*
+/**
* Return status of sound
*/
bool_t sound_is_active()
@@ -132,7 +132,7 @@ bool_t sound_is_active()
return var_sound_is_active;
}
-/*
+/**
* Shutdown sound
*/
void sound_quit()
diff --git a/cmake/FindCairo.cmake b/cmake/FindCairo.cmake
index 54da0d6..8f7bbd7 100644
--- a/cmake/FindCairo.cmake
+++ b/cmake/FindCairo.cmake
@@ -30,16 +30,16 @@ ELSE(CAIRO_LIBRARIES AND CAIRO_INCLUDE_DIR)
/usr
NO_DEFAULT_PATH
)
# handle the QUIETLY and REQUIRED arguments and set ZIP_FOUND to TRUE if
# all listed variables are TRUE
INCLUDE(FindPackageHandleStandardArgs)
- FIND_PACKAGE_HANDLE_STANDARD_ARGS(ZIP DEFAULT_MSG ZIP_LIBRARIES ZIP_INCLUDE_DIR)
- IF(NOT ZIP_FOUND)
- IF(ZIP_REQUIRED)
+ FIND_PACKAGE_HANDLE_STANDARD_ARGS(CAIRO DEFAULT_MSG CAIRO_LIBRARIES CAIRO_INCLUDE_DIR)
+ IF(NOT CAIRO_FOUND)
+ IF(CAIRO_REQUIRED)
MESSAGE(FATAL_ERROR "libcairo not found")
- ENDIF(ZIP_REQUIRED)
- SET(ZIP_LIBRARIES)
- ENDIF(NOT ZIP_FOUND)
+ ENDIF(CAIRO_REQUIRED)
+ SET(CAIRO_LIBRARIES)
+ ENDIF(NOT CAIRO_FOUND)
ENDIF(CAIRO_LIBRARIES AND CAIRO_INCLUDE_DIR)
MARK_AS_ADVANCED( CAIRO_LIBRARIES CAIRO_INCLUDE_DIR )
@@ -30,16 +30,16 @@ ELSE(CAIRO_LIBRARIES AND CAIRO_INCLUDE_DIR)
NO_DEFAULT_PATH
)
- # handle the QUIETLY and REQUIRED arguments and set ZIP_FOUND to TRUE if
+ # handle the QUIETLY and REQUIRED arguments and set CAIRO_FOUND to TRUE if
# all listed variables are TRUE
INCLUDE(FindPackageHandleStandardArgs)